# Installition

gpuRIR is a GPU supported Python package that can be used to generate impulse responses for audio signals. It can speed up the generation of impulse responses. Installing it is simple:

```shell
pip install https://github.com/DavidDiazGuerra/gpuRIR/zipball/master
```

Then, you can use pypi install the remaining dependencies:

```shell
pip install audioinfo -U
```
